@@ -27,16 +27,43 @@ enum phonebook_number_type {
 	TEL_TYPE_OTHER,
 };
 
+enum phonebook_call_type {
+	CALL_TYPE_NOT_A_CALL,
+	CALL_TYPE_MISSED,
+	CALL_TYPE_INCOMING,
+	CALL_TYPE_OUTGOING,
+};
+
+struct phonebook_number {
+	char *tel;
+	int type;
+};
+
 struct phonebook_contact {
 	char *fullname;
 	char *given;
 	char *family;
 	char *additional;
-	char *tel;
-	int tel_type;
-	char *email;
+	GSList *numbers;
+	GSList *emails;
 	char *prefix;
 	char *suffix;
+	char *pobox;
+	char *extended;
+	char *street;
+	char *locality;
+	char *region;
+	char *postal;
+	char *country;
+	char *birthday;
+	char *nickname;
+	char *website;
+	char *photo;
+	char *company;
+	char *department;
+	char *title;
+	char *datetime;
+	int calltype;
 };
 
 void phonebook_add_contact(GString *vcards, struct phonebook_contact *contact,
